amalgame/commit

RENAME: Remove references to confusing amalgame:Alignment class

authorJacco van Ossenbruggen
Thu Aug 28 13:28:20 2014 +0200
committerJacco van Ossenbruggen
Thu Aug 28 13:28:20 2014 +0200
commit72b993f12c71f0ae64d81a5fd1e47b8baf6a10d8
treeb9b48792e1d9c247a9150bc8f7ab3d5826afdb4d
parentfc1a4a0633474a285e0acf44b2f2468b71a1b585
Diff style: patch stat
diff --git a/api/node_info.pl b/api/node_info.pl
index 80249f3..fa1a97c 100644
--- a/api/node_info.pl
+++ b/api/node_info.pl
@@ -11,7 +11,6 @@
 
 :- use_module(library(skos/util)).
 
-
 :- use_module(library(amalgame/amalgame_modules)).
 :- use_module(library(amalgame/ag_stats)).
 :- use_module(library(amalgame/voc_stats)).
@@ -346,14 +345,14 @@ label_lang_stat(Scheme, _Strategy, Property, Langs,
 	).
 
 
-%%	amalgame_provenance(+R, +Alignment, -Provenance:[key-value])
+%%	amalgame_provenance(+R, +Strategy, -Provenance:[key-value])
 %
 %	Provenance is a list of key-value pairs with provenance about
-%	node R as defined by strategy Alignment
+%	node R as defined by Strategy.
 
 
-amalgame_provenance(R, Alignment, Provenance) :-
-	findall(Key-Value, ag_prov(R, Alignment, Key, Value), Provenance0),
+amalgame_provenance(R, Strategy, Provenance) :-
+	findall(Key-Value, ag_prov(R, Strategy, Key, Value), Provenance0),
 	sort(Provenance0,Provenance).
 
 ag_prov(R, A, 'defined by', \rdf_link(Agent)) :-
diff --git a/api/strategy_viz.pl b/api/strategy_viz.pl
index 371d6c4..d9adb44 100644
--- a/api/strategy_viz.pl
+++ b/api/strategy_viz.pl
@@ -169,7 +169,7 @@ amalgame_shape(R, [shape(ellipse),
 	      style(filled),
               fontsize(10)]) :-
 	atom(R),
-	rdfs_individual_of(R, amalgame:'Alignment'),
+	rdfs_individual_of(R, amalgame:'Mapping'),
 	!,
 	artifact_color(R, Color).
 amalgame_shape(_R, [shape(box),
diff --git a/applications/publisher.pl b/applications/publisher.pl
index 4265b30..93acca0 100644
--- a/applications/publisher.pl
+++ b/applications/publisher.pl
@@ -55,10 +55,10 @@ http_ag_publish(Request) :-
 	expand_file_search_path(alignment_results(.), L),
 	exists_directory(L),
 	absolute_file_name(L,BaseDir),!,
-	file_base_name(Strategy, AlignmentB),
-	atomic_list_concat([BaseDir, AlignmentB], '/', Dir),
+	file_base_name(Strategy, StrategyBase),
+	atomic_list_concat([BaseDir, StrategyBase], '/', Dir),
 	save_mappings(Strategy, Dir, [status(Status), format(Format),default_relation(DefaultRelation)]),
-	http_redirect(moved, alignment_results(AlignmentB), Request).
+	http_redirect(moved, alignment_results(StrategyBase), Request).
 
 
 		 /*******************************
diff --git a/applications/startpage.pl b/applications/startpage.pl
index 75a32a4..a2dfeca 100644
--- a/applications/startpage.pl
+++ b/applications/startpage.pl
@@ -37,7 +37,7 @@ html_schemes_only -->
 	html_new(ConceptSchemes).
 
 html_main_page(_Request) :-
-	findall(A-S, amalgame_strategy_schemes(A, S), Alignments),
+	findall(A-S, amalgame_strategy_schemes(A, S), StrategySchemePairs),
 	amalgame_alignable_schemes(ConceptSchemes),
 	reply_html_page(cliopatria(main),
 			[ title(['Amalgame - strategies'])
@@ -54,10 +54,10 @@ html_main_page(_Request) :-
 				    [
 					div([id(content), class('yui3-accordion')],
 					    [
-						\html_open(Alignments),
+						\html_open(StrategySchemePairs),
 						\html_reference,
 						\html_import,
-						\html_publish(Alignments),
+						\html_publish(StrategySchemePairs),
 						\html_new(ConceptSchemes)
 					    ])
 				    ]),
diff --git a/components/amalgame/startpage.pl b/components/amalgame/startpage.pl
index d9b3697..31aac6e 100644
--- a/components/amalgame/startpage.pl
+++ b/components/amalgame/startpage.pl
@@ -66,7 +66,7 @@ html_new(_) -->
 		      [inactive]
 		     ).
 
-%%	html_open(+Alignments)
+%%	html_open(+StrategySchemePairs)
 %
 %
 html_open([]) -->
diff --git a/lib/ag_modules/best_numeric.pl b/lib/ag_modules/best_numeric.pl
index 349517a..8d35ad6 100644
--- a/lib/ag_modules/best_numeric.pl
+++ b/lib/ag_modules/best_numeric.pl
@@ -17,12 +17,12 @@ amalgame_module(amalgame:'BestNumeric').
 %
 %
 
-selecter(AlignmentGraph, Sel, Disc, Und, Options) :-
+selecter(Mapping, Sel, Disc, Und, Options) :-
 	option(type(SourceOrTarget), Options, target),
 	(   SourceOrTarget = target
-	->  partition_(SourceOrTarget, AlignmentGraph, Sel, Disc, Und)
-	;   predsort(ag_map:compare_align(target), AlignmentGraph, SortedAlignmentGraph),
-	    partition_(SourceOrTarget, SortedAlignmentGraph, Sel0, Disc0, Und0),
+	->  partition_(SourceOrTarget, Mapping, Sel, Disc, Und)
+	;   predsort(ag_map:compare_align(target), Mapping, TSorted),
+	    partition_(SourceOrTarget, TSorted, Sel0, Disc0, Und0),
 	    predsort(ag_map:compare_align(source), Sel0,  Sel),
 	    predsort(ag_map:compare_align(source), Disc0, Disc),
 	    predsort(ag_map:compare_align(source), Und0,  Und)
diff --git a/lib/ag_modules/most_generic.pl b/lib/ag_modules/most_generic.pl
index 71f0318..7e8e754 100644
--- a/lib/ag_modules/most_generic.pl
+++ b/lib/ag_modules/most_generic.pl
@@ -20,13 +20,13 @@ amalgame_module(amalgame:'MostGeneric').
 %
 %
 
-selecter(AlignmentGraph, Sel, Disc, Und, Options) :-
+selecter(Mapping, Sel, Disc, Und, Options) :-
 	option(type(SourceOrTarget), Options, target),
 	option(most_least(Most), Options, most),
 	(   SourceOrTarget = target
-	->  partition_(SourceOrTarget, Most, AlignmentGraph, Sel, Disc, Und)
-	;   predsort(ag_map:compare_align(target), AlignmentGraph, SortedAlignmentGraph),
-	    partition_(SourceOrTarget, Most, SortedAlignmentGraph, Sel0, Disc0, Und0),
+	->  partition_(SourceOrTarget, Most, Mapping, Sel, Disc, Und)
+	;   predsort(ag_map:compare_align(target), Mapping, TSorted),
+	    partition_(SourceOrTarget, Most, TSorted, Sel0, Disc0, Und0),
 	    predsort(ag_map:compare_align(source), Sel0,  Sel),
 	    predsort(ag_map:compare_align(source), Disc0, Disc),
 	    predsort(ag_map:compare_align(source), Und0,  Und)
diff --git a/lib/ag_modules/most_labels.pl b/lib/ag_modules/most_labels.pl
index 35d0bf4..4b8766a 100644
--- a/lib/ag_modules/most_labels.pl
+++ b/lib/ag_modules/most_labels.pl
@@ -20,18 +20,17 @@ amalgame_module(amalgame:'MostLabels').
 %
 %	Source is sorted (e.g. on S).
 
-selecter(AlignmentGraph, Sel, Disc, Und, Options) :-
+selecter(Mapping, Sel, Disc, Und, Options) :-
 	option(type(SourceOrTarget), Options, target),
 	(   SourceOrTarget = target
-	->  partition_(SourceOrTarget, AlignmentGraph, Sel, Disc, Und)
-	;   predsort(ag_map:compare_align(target), AlignmentGraph, SortedAlignmentGraph),
-	    partition_(SourceOrTarget, SortedAlignmentGraph, Sel0, Disc0, Und0),
+	->  partition_(SourceOrTarget, Mapping, Sel, Disc, Und)
+	;   predsort(ag_map:compare_align(target), Mapping, TSorted),
+	    partition_(SourceOrTarget, TSorted, Sel0, Disc0, Und0),
 	    predsort(ag_map:compare_align(source), Sel0,  Sel),
 	    predsort(ag_map:compare_align(source), Disc0, Disc),
 	    predsort(ag_map:compare_align(source), Und0,  Und)
 	).
 
-
 %%	partition(+Input, -Output, +Options)
 %
 %	Output a list of graphs where the first element contains
diff --git a/lib/ag_modules/most_methods.pl b/lib/ag_modules/most_methods.pl
index 7de0f0e..94aee5b 100644
--- a/lib/ag_modules/most_methods.pl
+++ b/lib/ag_modules/most_methods.pl
@@ -23,13 +23,13 @@ amalgame_module(amalgame:'MostMethods').
 %
 %       Source is a sorted list of alignment terms.
 
-selecter(AlignmentGraph, S, D, U, Options) :-
+selecter(Mapping, S, D, U, Options) :-
 	option(type(target), Options, target),!,
-	partition_(target, AlignmentGraph, S, D, U).
-selecter(AlignmentGraph, S, D, U, Options) :-
+	partition_(target, Mapping, S, D, U).
+selecter(Mapping, S, D, U, Options) :-
 	option(type(source), Options, target),!,
-	predsort(ag_map:compare_align(target), AlignmentGraph, SortedAlignmentGraph),
-	partition_(source, SortedAlignmentGraph, Sel0, Disc0, Und0),
+	predsort(ag_map:compare_align(target), Mapping, TSorted),
+	partition_(source, TSorted, Sel0, Disc0, Und0),
 	predsort(ag_map:compare_align(source), Sel0,  S),
 	predsort(ag_map:compare_align(source), Disc0, D),
 	predsort(ag_map:compare_align(source), Und0,  U).
diff --git a/lib/ag_modules/sibling_selecter.pl b/lib/ag_modules/sibling_selecter.pl
index bce60f3..2427b94 100644
--- a/lib/ag_modules/sibling_selecter.pl
+++ b/lib/ag_modules/sibling_selecter.pl
@@ -1,6 +1,5 @@
 :- module(sibling_selecter,[]).
 
-:- use_module(library(semweb/rdf_db)).
 :- use_module(library(skos/util)).
 :- use_module(library(amalgame/map)).
 
@@ -22,13 +21,13 @@ amalgame_module(amalgame:'SiblingSelecter').
 %
 %
 
-selecter(AlignmentGraph, SelP, [], Und, Options) :-
+selecter(SSorted, SelP, [], Und, Options) :-
 	option(depth(Depth), Options, 2),
 	option(type(SourceOrTarget), Options, source),
 	(   SourceOrTarget = target
-	->  partition_(SourceOrTarget, AlignmentGraph, Depth, Sel, Und)
-	;   predsort(ag_map:compare_align(target), AlignmentGraph, SortedAlignmentGraph),
-	    partition_(SourceOrTarget, SortedAlignmentGraph, Depth, Sel0, Und0),
+	->  partition_(SourceOrTarget, SSorted, Depth, Sel, Und)
+	;   predsort(ag_map:compare_align(target), SSorted, TSorted),
+	    partition_(SourceOrTarget, TSorted, Depth, Sel0, Und0),
 	    predsort(ag_map:compare_align(source), Sel0,  Sel),
 	    predsort(ag_map:compare_align(source), Und0,  Und)
 	),
diff --git a/lib/ag_modules/voc_exclude.pl b/lib/ag_modules/voc_exclude.pl
index 34eb8bf..d4f018d 100644
--- a/lib/ag_modules/voc_exclude.pl
+++ b/lib/ag_modules/voc_exclude.pl
@@ -40,49 +40,3 @@ mapping_concepts(source, Mapping, Concepts) :-
 	maplist(arg(1), Mapping, Concepts).
 mapping_concepts(target, Mapping, Concepts) :-
 	maplist(arg(2), Mapping, Concepts).
-
-/*
-
-concept_selecter(scheme(SourceVoc), Result, Options) :-
-	option(exclude_sources(Exc), Options),!,
-	maplist(align_source, Exc, ExcSrcs),
-	findall(S, vocab_member(S, scheme(SourceVoc)), Sources),
-
-	sort(Sources, SsSorted),
-	sort(ExcSrcs, EsSorted),
-	ord_subtract(SsSorted, EsSorted, SelSourceVoc),
-	(   option(targetvoc(TargetVoc), Options)
-	->  maplist(align_source(TargetVoc), Result, SelSourceVoc)
-	;   maplist(align_source, Result, SelSourceVoc)
-	).
-
-concept_selecter(SourceAlignment, TargetAlignment, Options) :-
-	option(exclude_sources(Exc), Options),!,
-	voc_exclude(source, SourceAlignment, Exc, [], TargetAlignment0),
-	predsort(ag_map:compare_align(target), TargetAlignment0, TargetAlignment).
-
-concept_selecter(SourceAlignment, TargetAlignment, Options) :-
-	option(exclude_targets(Exc), Options),!,
-	debug(align, 'Running target selector', []),
-	predsort(ag_map:compare_align(target), SourceAlignment, SourceAlignmentSorted),
-	predsort(ag_map:compare_align(target), Exc, ExcSorted),
-	voc_exclude(target, SourceAlignmentSorted, ExcSorted, [], TargetAlignment0),
-	predsort(ag_map:compare_align(target), TargetAlignment0, TargetAlignment).
-
-voc_exclude(_Type, L, [], Accum, Result) :- !, append(Accum, L, Result).
-voc_exclude(_Type, [], _, Accum, Accum) :- !.
-voc_exclude(Type, [A|ATail], [E|ETail], Accum, Result) :-
-	compare_align(Type, Order, A, E),
-	(   Order == '='
-	->  voc_exclude(Type, ATail, [E|ETail], Accum, Result)
-	;   Order == '<'
-	->  voc_exclude(Type, ATail, [E|ETail], [A|Accum], Result)
-	;   Order == '>'
-	->  voc_exclude(Type, [A|ATail], ETail, Accum, Result)
-	).
-
-align_source(TargetVoc, align(S,scheme(TargetVoc),[]), S).
-
-align_source(align(S1,_,P), S2) :- (nonvar(S2) -> P=[]; true), S1=S2.
-% align_target(align(_,T1,P), T2) :- (nonvar(T2) -> P=[]; true), T1=T2.
-*/
diff --git a/lib/amalgame/map.pl b/lib/amalgame/map.pl
index 5825efd..a32581a 100644
--- a/lib/amalgame/map.pl
+++ b/lib/amalgame/map.pl
@@ -317,9 +317,9 @@ group_provenance(As, S, T, P, [align(S, T, Psorted)|Gs]) :-
         merge_provenance(As, Gs).
 
 
-%%      materialize_alignment_graph(+Alignments, +Options)
+%%      materialize_alignment_graph(+Mappings, +Options)
 %
-%       Assert Alignments as triples in the store.
+%       Assert Mappings as triples in the store.
 
 materialize_mapping_graph(Input, Options) :-
         option(graph(Graph), Options, test),
diff --git a/rdf/tool/amalgame.ttl b/rdf/tool/amalgame.ttl
index 34e39ab..60c70bd 100644
--- a/rdf/tool/amalgame.ttl
+++ b/rdf/tool/amalgame.ttl
@@ -13,6 +13,11 @@ amalgame:AlignmentStrategy
     rdfs:label "alignment strategy"@en ;
     rdfs:comment "RDF representation of an alignment strategy that can be loaded and executed by Amalgame"@en.
 
+amalgame:Entity
+    rdfs:label "entity"@en ;
+    rdfs:comment "Top class for all amalgame data entities, including mappings and vocabularies"@en ;
+    rdfs:subClassOf prov:Entity .
+
 amalgame:Process
     rdfs:label "process"@en ;
     rdfs:comment "Top class for all amalgame processes"@en ;
@@ -58,86 +63,68 @@ amalgame:Merger
 
 amalgame:includes
         rdfs:domain skos:ConceptScheme ;
-        rdfs:range amalgame:Alignment .
+        rdfs:range amalgame:AlignmentStrategy .
 amalgame:input
 	rdfs:domain prov:Activity ;
-	rdfs:range  amalgame:Alignment ;
+	rdfs:range  amalgame:Entity ;
 	rdfs:subPropertyOf prov:used.
-
-amalgame:exclude
-	rdfs:domain prov:Activity ;
-	rdfs:range  amalgame:Alignment ;
-	rdfs:subPropertyOf amalgame:secondary_input .
 amalgame:secondary_input
 	rdfs:domain prov:Activity ;
-	rdfs:range  amalgame:Alignment ;
+	rdfs:range  amalgame:Entity ;
 	rdfs:subPropertyOf prov:used .
 
 amalgame:wasGeneratedBy rdfs:subPropertyOf prov:wasGeneratedBy.
-# prov:wasGeneratedBy rdfs:subPropertyOf amalgame:wasGeneratedBy.
 
 amalgame:selectedBy
-	rdfs:domain  amalgame:Alignment ;
+	rdfs:domain  amalgame:Mapping ;
 	rdfs:range prov:Activity ;
 	rdfs:subPropertyOf amalgame:wasGeneratedBy.
 
 amalgame:discardedBy
-	rdfs:domain  amalgame:Alignment ;
+	rdfs:domain  amalgame:Mapping ;
 	rdfs:range prov:Activity ;
 	rdfs:subPropertyOf amalgame:wasGeneratedBy.
 
 amalgame:undecidedBy
-	rdfs:domain  amalgame:Alignment ;
+	rdfs:domain  amalgame:Mapping ;
 	rdfs:range prov:Activity ;
 	rdfs:subPropertyOf amalgame:wasGeneratedBy.
 
 amalgame:evaluationOf
 	rdfs:subPropertyOf prov:wasDerivedFrom.
 
-amalgame:NoAlignmentGraph a rdfs:Class ;
-	rdfs:label "No Alignment Graph"@en ;
-	rdfs:comment "The class of all Named Graphs in the repository containing no mappings and/or alignments."@en.
-
-amalgame:Alignment a rdfs:Class ;
-    rdfs:subClassOf prov:Entity ;
-	rdfs:label "Alignment Graph"@en ;
-	rdfs:comment "The class of all Named Graphs in the repository containing mappings and/or alignments."@en.
-
 amalgame:Mapping a rdfs:Class ;
-	rdfs:subClassOf amalgame:Alignment .
+	rdfs:subClassOf prov:Entity ;
+	rdfs:label "Mapping Graph"@en ;
+	rdfs:comment "The class of all Named Graphs in the repository containing correspondences."@en.
 
 amalgame:LoadedMapping a rdfs:Class ;
 	rdfs:subClassOf amalgame:Mapping ;
 	rdfs:label "Loaded Mapping Graph"@en ;
 	rdfs:comment "An alignment loaded from file, e.g. not derived from another alignment"@en.
 
-amalgame:AmalgameAlignment a rdfs:Class ;
-	rdfs:subClassOf amalgame:Alignment ;
-	rdfs:label "Amalgame Alignment Graph"@en ;
-	rdfs:comment "An alignment created by Amalgame's matchers, e.g. not derived from another alignment"@en.
-
-amalgame:DerivedAlignment a rdfs:Class ;
-	rdfs:subClassOf amalgame:Alignment ;
-	rdfs:label "Derived Alignment Graph"@en ;
-	rdfs:comment "An alignment derived from another alignment"@en.
+amalgame:DerivedMapping a rdfs:Class ;
+	rdfs:subClassOf amalgame:Mapping ;
+	rdfs:label "Derived Mapping Graph"@en ;
+	rdfs:comment "An mapping derived from another mapping"@en.
 
-amalgame:OverlapAlignment a rdfs:Class;
-	rdfs:subClassOf amalgame:DerivedAlignment ;
+amalgame:OverlapMapping a rdfs:Class;
+	rdfs:subClassOf amalgame:DerivedMapping ;
 	rdfs:label "Amalgame Overlap"@en ;
 	rdfs:comment "A Named Graph that describes the overlap of one or more other named graphs, these constituents are denoted by the amalgame:member property."@en .
 
-amalgame:SampleAlignment a rdfs:Class;
-	rdfs:subClassOf amalgame:DerivedAlignment ;
+amalgame:SampleMapping a rdfs:Class;
+	rdfs:subClassOf amalgame:DerivedMapping ;
 	rdfs:label "Amalgame Sample"@en ;
 	rdfs:comment "A Named Graph that describes a sample of another named graph, denoted by dcterms:source in the amalgame:provenance section."@en .
 
-amalgame:ExportedAlignment a rdfs:Class;
-	rdfs:subClassOf amalgame:DerivedAlignment ;
+amalgame:ExportedMapping a rdfs:Class;
+	rdfs:subClassOf amalgame:DerivedMapping ;
 	rdfs:label "Amalgame Exported"@en ;
 	rdfs:comment "A Named Graph that has been created by exporting another named graph into a new format. The source graph is recorded by dcterms:source in the amalgame:provenance section."@en .
 
-amalgame:PartitionedAlignment a rdfs:Class;
-	rdfs:subClassOf amalgame:DerivedAlignment ;
+amalgame:PartitionedMapping a rdfs:Class;
+	rdfs:subClassOf amalgame:DerivedMapping ;
 	rdfs:label "Amalgame Partitioned"@en ;
 	rdfs:comment "A Named Graph that has been created by partitioning another named graph into one or more new graphs. The source graph is recorded by dcterms:source in the amalgame:provenance section."@en .
 
@@ -146,8 +133,8 @@ amalgame:EvaluatedMapping a rdfs:Class;
 	rdfs:label "Amalgame Evaluation Results"@en ;
 	rdfs:comment "A Named Graph that has been created by manually evaluating another named graph into a new graph. The source graph is recorded by the amalgame:evaluationOf property."@en .
 
-amalgame:SelectionAlignment a rdfs:Class;
-	rdfs:subClassOf amalgame:DerivedAlignment ;
+amalgame:SelectionMapping a rdfs:Class;
+	rdfs:subClassOf amalgame:DerivedMapping ;
 	rdfs:label "Amalgame Selection Results"@en ;
 	rdfs:comment "A Named Graph that has been created by selecting mappings from  another named graph into a new graph. The source graph is recorded by dcterms:source in the amalgame:provenance section."@en .
 
@@ -172,37 +159,37 @@ amalgame:DerivedConceptScheme a rdfs:Class;
 
 amalgame:member a rdf:Property ;
 	rdfs:label "overlap member"@en ;
-	rdfs:comment "Used to define the alignment graphs that define an OverlapAlignment."@en ;
-	rdfs:domain amalgame:OverlapAlignment ;
-	rdfs:range amalgame:Alignment .
+	rdfs:comment "Used to define the alignment graphs that define an OverlapMapping."@en ;
+	rdfs:domain amalgame:OverlapMapping ;
+	rdfs:range amalgame:Mapping .
 
 amalgame:overlap_set
 	a rdf:Property ;
-	rdfs:domain amalgame:Alignment ;
+	rdfs:domain amalgame:Mapping ;
 	rdfs:range rdfs:Literal .
 
 amalgame:totalCount a rdf:Property, owl:FunctionalProperty ;
 	rdfs:label "total map count" ;
 	rdfs:comment "The number of mappings in this Aligment" ;
-	rdfs:domain amalgame:Alignment ;
+	rdfs:domain amalgame:Mapping ;
 	rdfs:range xsd:int .
 
 amalgame:format a rdf:Property , owl:FunctionalProperty ;
 	rdfs:label "mapping format" ;
 	rdfs:comment "The format of the mappings in this Aligment, assuming a graph contains only one format." ;
-	rdfs:domain amalgame:Alignment ;
+	rdfs:domain amalgame:Mapping ;
 	rdfs:range rdfs:Literal .
 
 amalgame:mappedSourceConcepts a rdf:Property, owl:FunctionalProperty ;
-	rdfs:domain amalgame:Alignment ;
+	rdfs:domain amalgame:Mapping ;
 	rdfs:range xsd:int .
 
 amalgame:mappedTargetConcepts a rdf:Property, owl:FunctionalProperty ;
-	rdfs:domain amalgame:Alignment ;
+	rdfs:domain amalgame:Mapping ;
 	rdfs:range xsd:int .
 
 amalgame:nickname a rdf:Property , owl:FunctionalProperty ;
-	rdfs:domain amalgame:Alignment ;
+	rdfs:domain amalgame:Mapping ;
 	rdfs:range rdfs:Literal .
 
 amalgame:source a rdf:Property ;
@@ -238,7 +225,7 @@ amalgame:numberOfMappedConcepts a rdf:Property , owl:FunctionalProperty ;
 amalgame:provenance a rdf:Property ;
 	rdfs:label "provenance informaton"@en;
 	rdfs:comment "Could link to any resource describing provenance information about this alignment graph"@en ;
-	rdfs:domain amalgame:Alignment ;
+	rdfs:domain amalgame:Mapping ;
 	rdfs:range amalgame:Provenance .
 
 amalgame:request a rdf:Property, owl:FunctionalProperty ;
@@ -296,7 +283,7 @@ amalgame:publish_ns
 
 amalgame:default_relation
 	a rdf:Property ;
-	rdfs:domain amalgame:Alignment ;
+	rdfs:domain amalgame:Mapping ;
 	rdfs:range rdf:Property .
 
 evaluator:unrelated
diff --git a/config-available/ag_strat_prov_graph_viz.pl b/config-available/ag_strat_prov_graph_viz.pl
index 00b0054..8183c0c 100644
--- a/config-available/ag_strat_prov_graph_viz.pl
+++ b/config-available/ag_strat_prov_graph_viz.pl
@@ -17,7 +17,7 @@ cliopatria:context_graph(URI, RDF) :-
 	;   rdfs_individual_of(URI, prov:'Activity')
 	;   rdfs_individual_of(URI, prov:'Agent')
 	;   skos_is_vocabulary(URI)
-	;   rdfs_individual_of(URI, amalgame:'Alignment')
+	;   rdfs_individual_of(URI, amalgame:'Entity')
 	),
 	findall(T, prov_context_triple(URI, T), RDF0),
 	sort(RDF0, RDF1),
@@ -87,20 +87,20 @@ transitive_context(prov:used).
 transitive_context(prov:wasInfluencedBy).
 
 blacklist(Orig, Overlap) :-
-	rdfs_individual_of(Overlap, amalgame:'OverlapAlignment'),
-	\+ rdfs_individual_of(Orig, amalgame:'OverlapAlignment'),
+	rdfs_individual_of(Overlap, amalgame:'OverlapMapping'),
+	\+ rdfs_individual_of(Orig, amalgame:'OverlapMapping'),
 	\+ rdf_has(_Overlap, prov:wasGeneratedBy,Orig).
 
 blacklist(Orig, OverlapProcess) :-
 	rdf_has(Overlap, prov:wasGeneratedBy, OverlapProcess),
-	rdfs_individual_of(Overlap, amalgame:'OverlapAlignment'),
-	\+ rdfs_individual_of(Orig, amalgame:'OverlapAlignment').
+	rdfs_individual_of(Overlap, amalgame:'OverlapMapping'),
+	\+ rdfs_individual_of(Orig, amalgame:'OverlapMapping').
 
 
 % Alignment made with amalgame:
 cliopatria:node_shape(URI, Shape, _Options) :-
 	rdf_has(URI, rdf:type, prov:'Entity'),
-	rdfs_individual_of(URI, amalgame:'Alignment'),
+	rdfs_individual_of(URI, amalgame:'Mapping'),
 	rdf_has(URI, prov:wasInfluencedBy, _),
 	Shape = [shape('Mdiamond'),fontize('20.00'), style(filled),fillcolor('#FF8888')].
 % Amalgame process:
@@ -108,12 +108,12 @@ cliopatria:node_shape(URI, Shape, _Options) :-
 	rdfs_individual_of(URI, prov:'Activity'),
 	Shape = [shape('box'), style(filled),fillcolor('#FF8888')].
 
 % Alignment (up)loaded, typically not made with amalgame
 cliopatria:node_shape(URI, Shape, _Options) :-
-	rdfs_individual_of(URI, amalgame:'Alignment'),
+	rdfs_individual_of(URI, amalgame:'LoadedMapping'),
 	Shape = [shape('Mdiamond'), style(filled),fillcolor('#AAAAAA')].
 
-% Vocabulary (up)loaded, typically not made with amalgame
+% Vocabulary (up)loaded or made with amalgame
 cliopatria:node_shape(URI, Shape, _Options) :-
 	skos_is_vocabulary(URI),
 	Shape = [shape(box3d),style(filled),fillcolor('#AAAAAA')].
@@ -87,20 +87,20 @@ transitive_context(prov:used).
 
 
-% Alignment made with amalgame:
+% Mapping made with amalgame:
 cliopatria:node_shape(URI, Shape, _Options) :-
 	rdf_has(URI, rdf:type, prov:'Entity'),
@@ -108,12 +108,12 @@ cliopatria:node_shape(URI, Shape, _Options) :-
 	Shape = [shape('box'), style(filled),fillcolor('#FF8888')].
 
-% Alignment (up)loaded, typically not made with amalgame
+% Mapping (up)loaded, typically not made with amalgame
 cliopatria:node_shape(URI, Shape, _Options) :-